pub struct GoogleCloudWebriskV1RiceDeltaEncoding {
pub encoded_data: Option<Vec<u8>>,
pub entry_count: Option<i32>,
pub first_value: Option<i64>,
pub rice_parameter: Option<i32>,
}Expand description
The Rice-Golomb encoded data. Used for sending compressed 4-byte hashes or compressed removal indices.
This type is not used in any activity, and only used as part of another schema.
Fields
encoded_data: Option<Vec<u8>>The encoded deltas that are encoded using the Golomb-Rice coder.
entry_count: Option<i32>The number of entries that are delta encoded in the encoded data. If only a single integer was encoded, this will be zero and the single value will be stored in first_value.
first_value: Option<i64>The offset of the first entry in the encoded data, or, if only a single integer was encoded, that single integer’s value. If the field is empty or missing, assume zero.
rice_parameter: Option<i32>The Golomb-Rice parameter, which is a number between 2 and 28. This field is missing (that is, zero) if num_entries is zero.