pub struct HashMethods<'a, C>where
C: 'a,{ /* private fields */ }Expand description
A builder providing access to all methods supported on hash resources.
It is not used directly, but through the WebRisk hub.
Example
Instantiate a resource builder
extern crate hyper;
extern crate hyper_rustls;
extern crate google_webrisk1 as webrisk1;
use webrisk1::{WebRisk, FieldMask, hyper_rustls, hyper_util, yup_oauth2};
let secret: yup_oauth2::ApplicationSecret = Default::default();
let connector = hyper_rustls::HttpsConnectorBuilder::new()
.with_native_roots()
.unwrap()
.https_only()
.enable_http2()
.build();
let executor = hyper_util::rt::TokioExecutor::new();
let auth = yup_oauth2::InstalledFlowAuthenticator::with_client(
secret,
yup_oauth2::InstalledFlowReturnMethod::HTTPRedirect,
yup_oauth2::client::CustomHyperClientBuilder::from(
hyper_util::client::legacy::Client::builder(executor).build(connector),
),
).build().await.unwrap();
let client = hyper_util::client::legacy::Client::builder(
hyper_util::rt::TokioExecutor::new()
)
.build(
hyper_rustls::HttpsConnectorBuilder::new()
.with_native_roots()
.unwrap()
.https_or_http()
.enable_http2()
.build()
);
let mut hub = WebRisk::new(client, auth);
// Usually you wouldn't bind this to a variable, but keep calling *CallBuilders*
// like `search(...)`
// to build up your call.
let rb = hub.hashes();Implementations
Sourceimpl<'a, C> HashMethods<'a, C>
impl<'a, C> HashMethods<'a, C>
Sourcepub fn search(&self) -> HashSearchCall<'a, C>
pub fn search(&self) -> HashSearchCall<'a, C>
Create a builder to help you perform the following task:
Gets the full hashes that match the requested hash prefix. This is used after a hash prefix is looked up in a threatList and there is a match. The client side threatList only holds partial hashes so the client must query this method to determine if there is a full hash match of a threat.